#ifndef NT2_INCLUDE_FUNCTIONS_CORRECT_FMA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CORRECT_FMA_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/correct_fma.hpp>

#endif
